/********************************************************************************
** Form generated from reading UI file 'settingsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSDIALOG_H
#define UI_SETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QKeySequenceEdit>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "settings/ocrlanguageslistwidget.h"
#include "settings/shortcutsmodel/shortcutsview.h"
#include "settings/tesseractparameterstablewidget.h"

QT_BEGIN_NAMESPACE

class Ui_SettingsDialog
{
public:
    QVBoxLayout *settingsDialogLayout;
    QSplitter *splitter;
    QListWidget *pagesListWidget;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QStackedWidget *pagesStackedWidget;
    QWidget *generalPage;
    QVBoxLayout *generalLayout;
    QGroupBox *generalGroupBox;
    QFormLayout *formLayout;
    QLabel *localeLabel;
    QComboBox *localeComboBox;
    QLabel *mainWindowOrientationLabel;
    QComboBox *mainWindowOrientationComboBox;
    QLabel *windowModeLabel;
    QComboBox *windowModeComboBox;
    QLabel *translationNotificationTimeoutLabel;
    QSpinBox *translationNotificationTimeoutSpinBox;
    QCheckBox *showTrayIconCheckBox;
    QCheckBox *startMinimizedCheckBox;
    QCheckBox *autostartCheckBox;
    QSpacerItem *generalPageSpacer;
    QWidget *interfacePage;
    QVBoxLayout *interfaceLayout;
    QGroupBox *fontGroupBox;
    QFormLayout *formLayout_2;
    QLabel *fontNameLabel;
    QFontComboBox *fontNameComboBox;
    QLabel *fontSizeLabel;
    QSpinBox *fontSizeSpinBox;
    QGroupBox *popupInterfaceGroupBox;
    QGridLayout *popupBoxLayout;
    QSpinBox *popupHeightSpinBox;
    QLabel *popupWidthLabel;
    QSpinBox *popupWidthSpinBox;
    QSpinBox *popupOpacitySpinBox;
    QSlider *popupWidthSlider;
    QSlider *popupHeightSlider;
    QLabel *popupOpacityLabel;
    QLabel *popupWindowTimeoutLabel;
    QLabel *popupHeightLabel;
    QSpinBox *popupWindowTimeoutSpinBox;
    QSlider *popupOpacitySlider;
    QGroupBox *languageFormatGroupBox;
    QFormLayout *formLayout_3;
    QLabel *mainWindowLanguageFormatLabel;
    QComboBox *mainWindowLanguageFormatComboBox;
    QLabel *popupLanguageFormatLabel;
    QComboBox *popupLanguageFormatComboBox;
    QGroupBox *trayIconGroupBox;
    QFormLayout *formLayout_4;
    QLabel *trayIconLabel;
    QComboBox *trayIconComboBox;
    QLabel *customTrayIconLabel;
    QHBoxLayout *trayIconPathLayout;
    QLineEdit *customTrayIconEdit;
    QToolButton *customTrayIconButton;
    QSpacerItem *interfacePageSpacer;
    QWidget *translationPage;
    QWidget *widget;
    QVBoxLayout *verticalLayout_3;
    QLabel *translationProviderLabel;
    QComboBox *translationProviderComboBox;
    QSpacerItem *verticalSpacer;
    QGroupBox *langDetectionGroupBox;
    QFormLayout *formLayout_5;
    QLabel *primaryLangLabel;
    QComboBox *primaryLangComboBox;
    QLabel *secondaryLangLabel;
    QComboBox *secondaryLangComboBox;
    QCheckBox *forceSourceAutodetectCheckBox;
    QCheckBox *forceTranslationAutodetectCheckBox;
    QWidget *ttsPage;
    QVBoxLayout *ttsLayout;
    QGroupBox *ttsGroupBox;
    QFormLayout *ttsFormLayout;
    QLabel *ttsProviderLabel;
    QComboBox *ttsProviderComboBox;
    QSpacerItem *ttsVerticalSpacer;
    QWidget *mozhiPage;
    QVBoxLayout *translationLayout;
    QGroupBox *translationGroupBox;
    QVBoxLayout *translationBoxLayout;
    QCheckBox *sourceTranslitCheckBox;
    QCheckBox *translationTranslitCheckBox;
    QCheckBox *sourceTranscriptionCheckBox;
    QCheckBox *translationOptionsCheckBox;
    QCheckBox *examplesCheckBox;
    QCheckBox *sourceSimplificationCheckBox;
    QGroupBox *mozhiGroupBox;
    QHBoxLayout *horizontalLayout;
    QLabel *mozhiUrlLabel;
    QComboBox *mozhiUrlComboBox;
    QPushButton *detectFastestButton;
    QSpacerItem *translationPageSpacer;
    QWidget *ocrPage;
    QVBoxLayout *ocrLayout;
    QGroupBox *languagesGroupBox;
    QGridLayout *ocrLanguagesLayout;
    OcrLanguagesListWidget *ocrLanguagesListWidget;
    QLabel *ocrLanguagesPathLabel;
    QToolButton *ocrLanguagesPathButton;
    QLabel *downloadMoreLabel;
    QLineEdit *ocrLanguagesPathEdit;
    QGroupBox *ocrParametersGroupBox;
    QVBoxLayout *ocrParametersLayout;
    QCheckBox *convertLineBreaksCheckBox;
    QHBoxLayout *tesseractParametersTableHorizontalLayout;
    QVBoxLayout *tesseractParametersButtonsVerticalLayout;
    QSpacerItem *tesseractParametersButtonsVerticalSpacer1;
    QToolButton *tesseractParametersAddButton;
    QToolButton *tesseractParametersRemoveButton;
    QSpacerItem *tesseractParametersButtonsVerticalSpacer2;
    TesseractParametersTableWidget *tesseractParametersTableWidget;
    QGroupBox *screenCaptureGroupBox;
    QGridLayout *gridLayout;
    QLabel *rememverRegionLabel;
    QComboBox *rememberRegionComboBox;
    QLabel *captureDelayLabel;
    QSpinBox *captureDelaySpinBox;
    QCheckBox *showMagnifierCheckBox;
    QCheckBox *negateOcrCheckBox;
    QCheckBox *confirmOnReleaseCheckBox;
    QCheckBox *applyLightMaskCheckBox;
    QSpacerItem *ocrSpacer;
    QWidget *connectionPage;
    QVBoxLayout *connectionLayout;
    QGroupBox *proxyGroupBox;
    QFormLayout *formLayout_8;
    QLabel *proxyTypeLabel;
    QComboBox *proxyTypeComboBox;
    QLabel *proxyHostLabel;
    QLineEdit *proxyHostEdit;
    QLabel *proxyPortLabel;
    QSpinBox *proxyPortSpinbox;
    QLabel *proxyInfoLabel;
    QCheckBox *proxyAuthCheckBox;
    QLabel *proxyUsernameLabel;
    QLineEdit *proxyUsernameEdit;
    QLabel *proxyPasswordLabel;
    QLineEdit *proxyPasswordEdit;
    QLabel *proxyPasswordInfoLabel;
    QSpacerItem *proxyPageSpacer;
    QWidget *shortcutsPage;
    QVBoxLayout *shortcutsLayout;
    ShortcutsView *shortcutsTreeView;
    QCheckBox *globalShortcutsCheckBox;
    QPushButton *resetAllShortcutsButton;
    QGroupBox *shortcutGroupBox;
    QHBoxLayout *shortcutBoxLayout;
    QLabel *shortcutLabel;
    QKeySequenceEdit *shortcutSequenceEdit;
    QToolButton *acceptShortcutButton;
    QToolButton *clearShortcutButton;
    QToolButton *resetShortcutButton;
    QWidget *aboutPage;
    QVBoxLayout *verticalLayout;
    QLabel *logoLabel;
    QGroupBox *aboutGroupBox;
    QFormLayout *formLayout_9;
    QLabel *versionTitleLabel;
    QLabel *versionLabel;
    QLabel *licenseTitleLabel;
    QLabel *licenseLabel;
    QLabel *sourceTitleLabel;
    QLabel *sourceLabel;
    QLabel *backendTitleLabel;
    QLabel *backendLabel;
    QSpacerItem *aboutPageVerticalSpacer;
    QDialogButtonBox *dialogButtonBox;

    void setupUi(QDialog *SettingsDialog)
    {
        if (SettingsDialog->objectName().isEmpty())
            SettingsDialog->setObjectName("SettingsDialog");
        SettingsDialog->resize(850, 660);
        settingsDialogLayout = new QVBoxLayout(SettingsDialog);
        settingsDialogLayout->setObjectName("settingsDialogLayout");
        splitter = new QSplitter(SettingsDialog);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        pagesListWidget = new QListWidget(splitter);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("preferences-system")));
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("preferences-desktop-theme")));
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("accessories-dictionary")));
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("audio-volume-high")));
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem3->setIcon(icon3);
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("preferences-desktop-locale")));
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem4->setIcon(icon4);
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("scanner")));
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem5->setText(QString::fromUtf8("OCR"));
        __qlistwidgetitem5->setIcon(icon5);
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("preferences-system-network")));
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem6->setIcon(icon6);
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("preferences-desktop-keyboard")));
        QListWidgetItem *__qlistwidgetitem7 = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem7->setIcon(icon7);
        QIcon icon8(QIcon::fromTheme(QString::fromUtf8("dialog-information")));
        QListWidgetItem *__qlistwidgetitem8 = new QListWidgetItem(pagesListWidget);
        __qlistwidgetitem8->setIcon(icon8);
        pagesListWidget->setObjectName("pagesListWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pagesListWidget->sizePolicy().hasHeightForWidth());
        pagesListWidget->setSizePolicy(sizePolicy);
        pagesListWidget->setMaximumSize(QSize(200, 16777215));
        pagesListWidget->setIconSize(QSize(32, 32));
        pagesListWidget->setResizeMode(QListView::Adjust);
        splitter->addWidget(pagesListWidget);
        scrollArea = new QScrollArea(splitter);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 626, 609));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setObjectName("verticalLayout_2");
        pagesStackedWidget = new QStackedWidget(scrollAreaWidgetContents);
        pagesStackedWidget->setObjectName("pagesStackedWidget");
        generalPage = new QWidget();
        generalPage->setObjectName("generalPage");
        generalLayout = new QVBoxLayout(generalPage);
        generalLayout->setObjectName("generalLayout");
        generalGroupBox = new QGroupBox(generalPage);
        generalGroupBox->setObjectName("generalGroupBox");
        formLayout = new QFormLayout(generalGroupBox);
        formLayout->setObjectName("formLayout");
        localeLabel = new QLabel(generalGroupBox);
        localeLabel->setObjectName("localeLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(localeLabel->sizePolicy().hasHeightForWidth());
        localeLabel->setSizePolicy(sizePolicy1);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, localeLabel);

        localeComboBox = new QComboBox(generalGroupBox);
        localeComboBox->setObjectName("localeComboBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, localeComboBox);

        mainWindowOrientationLabel = new QLabel(generalGroupBox);
        mainWindowOrientationLabel->setObjectName("mainWindowOrientationLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, mainWindowOrientationLabel);

        mainWindowOrientationComboBox = new QComboBox(generalGroupBox);
        mainWindowOrientationComboBox->addItem(QString());
        mainWindowOrientationComboBox->addItem(QString());
        mainWindowOrientationComboBox->addItem(QString());
        mainWindowOrientationComboBox->setObjectName("mainWindowOrientationComboBox");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, mainWindowOrientationComboBox);

        windowModeLabel = new QLabel(generalGroupBox);
        windowModeLabel->setObjectName("windowModeLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, windowModeLabel);

        windowModeComboBox = new QComboBox(generalGroupBox);
        windowModeComboBox->addItem(QString());
        windowModeComboBox->addItem(QString());
        windowModeComboBox->addItem(QString());
        windowModeComboBox->setObjectName("windowModeComboBox");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, windowModeComboBox);

        translationNotificationTimeoutLabel = new QLabel(generalGroupBox);
        translationNotificationTimeoutLabel->setObjectName("translationNotificationTimeoutLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, translationNotificationTimeoutLabel);

        translationNotificationTimeoutSpinBox = new QSpinBox(generalGroupBox);
        translationNotificationTimeoutSpinBox->setObjectName("translationNotificationTimeoutSpinBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(translationNotificationTimeoutSpinBox->sizePolicy().hasHeightForWidth());
        translationNotificationTimeoutSpinBox->setSizePolicy(sizePolicy2);
        translationNotificationTimeoutSpinBox->setMinimum(1);
        translationNotificationTimeoutSpinBox->setMaximum(60);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, translationNotificationTimeoutSpinBox);

        showTrayIconCheckBox = new QCheckBox(generalGroupBox);
        showTrayIconCheckBox->setObjectName("showTrayIconCheckBox");

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, showTrayIconCheckBox);

        startMinimizedCheckBox = new QCheckBox(generalGroupBox);
        startMinimizedCheckBox->setObjectName("startMinimizedCheckBox");
        startMinimizedCheckBox->setEnabled(false);

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, startMinimizedCheckBox);

        autostartCheckBox = new QCheckBox(generalGroupBox);
        autostartCheckBox->setObjectName("autostartCheckBox");

        formLayout->setWidget(6, QFormLayout::ItemRole::SpanningRole, autostartCheckBox);


        generalLayout->addWidget(generalGroupBox);

        generalPageSpacer = new QSpacerItem(20, 138, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        generalLayout->addItem(generalPageSpacer);

        pagesStackedWidget->addWidget(generalPage);
        interfacePage = new QWidget();
        interfacePage->setObjectName("interfacePage");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Ignored, QSizePolicy::Policy::Ignored);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(interfacePage->sizePolicy().hasHeightForWidth());
        interfacePage->setSizePolicy(sizePolicy3);
        interfaceLayout = new QVBoxLayout(interfacePage);
        interfaceLayout->setObjectName("interfaceLayout");
        fontGroupBox = new QGroupBox(interfacePage);
        fontGroupBox->setObjectName("fontGroupBox");
        formLayout_2 = new QFormLayout(fontGroupBox);
        formLayout_2->setObjectName("formLayout_2");
        fontNameLabel = new QLabel(fontGroupBox);
        fontNameLabel->setObjectName("fontNameLabel");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, fontNameLabel);

        fontNameComboBox = new QFontComboBox(fontGroupBox);
        fontNameComboBox->setObjectName("fontNameComboBox");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, fontNameComboBox);

        fontSizeLabel = new QLabel(fontGroupBox);
        fontSizeLabel->setObjectName("fontSizeLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, fontSizeLabel);

        fontSizeSpinBox = new QSpinBox(fontGroupBox);
        fontSizeSpinBox->setObjectName("fontSizeSpinBox");
        fontSizeSpinBox->setSuffix(QString::fromUtf8(" pt"));
        fontSizeSpinBox->setMinimum(6);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, fontSizeSpinBox);


        interfaceLayout->addWidget(fontGroupBox);

        popupInterfaceGroupBox = new QGroupBox(interfacePage);
        popupInterfaceGroupBox->setObjectName("popupInterfaceGroupBox");
        popupBoxLayout = new QGridLayout(popupInterfaceGroupBox);
        popupBoxLayout->setObjectName("popupBoxLayout");
        popupHeightSpinBox = new QSpinBox(popupInterfaceGroupBox);
        popupHeightSpinBox->setObjectName("popupHeightSpinBox");
        popupHeightSpinBox->setSuffix(QString::fromUtf8(" px"));

        popupBoxLayout->addWidget(popupHeightSpinBox, 1, 2, 1, 1);

        popupWidthLabel = new QLabel(popupInterfaceGroupBox);
        popupWidthLabel->setObjectName("popupWidthLabel");

        popupBoxLayout->addWidget(popupWidthLabel, 2, 0, 1, 1);

        popupWidthSpinBox = new QSpinBox(popupInterfaceGroupBox);
        popupWidthSpinBox->setObjectName("popupWidthSpinBox");
        popupWidthSpinBox->setSuffix(QString::fromUtf8(" px"));

        popupBoxLayout->addWidget(popupWidthSpinBox, 2, 2, 1, 1);

        popupOpacitySpinBox = new QSpinBox(popupInterfaceGroupBox);
        popupOpacitySpinBox->setObjectName("popupOpacitySpinBox");
        popupOpacitySpinBox->setSuffix(QString::fromUtf8("%"));
        popupOpacitySpinBox->setMaximum(100);

        popupBoxLayout->addWidget(popupOpacitySpinBox, 0, 2, 1, 1);

        popupWidthSlider = new QSlider(popupInterfaceGroupBox);
        popupWidthSlider->setObjectName("popupWidthSlider");
        popupWidthSlider->setOrientation(Qt::Horizontal);

        popupBoxLayout->addWidget(popupWidthSlider, 2, 1, 1, 1);

        popupHeightSlider = new QSlider(popupInterfaceGroupBox);
        popupHeightSlider->setObjectName("popupHeightSlider");
        popupHeightSlider->setOrientation(Qt::Horizontal);

        popupBoxLayout->addWidget(popupHeightSlider, 1, 1, 1, 1);

        popupOpacityLabel = new QLabel(popupInterfaceGroupBox);
        popupOpacityLabel->setObjectName("popupOpacityLabel");

        popupBoxLayout->addWidget(popupOpacityLabel, 0, 0, 1, 1);

        popupWindowTimeoutLabel = new QLabel(popupInterfaceGroupBox);
        popupWindowTimeoutLabel->setObjectName("popupWindowTimeoutLabel");

        popupBoxLayout->addWidget(popupWindowTimeoutLabel, 3, 0, 1, 1);

        popupHeightLabel = new QLabel(popupInterfaceGroupBox);
        popupHeightLabel->setObjectName("popupHeightLabel");

        popupBoxLayout->addWidget(popupHeightLabel, 1, 0, 1, 1);

        popupWindowTimeoutSpinBox = new QSpinBox(popupInterfaceGroupBox);
        popupWindowTimeoutSpinBox->setObjectName("popupWindowTimeoutSpinBox");
        sizePolicy2.setHeightForWidth(popupWindowTimeoutSpinBox->sizePolicy().hasHeightForWidth());
        popupWindowTimeoutSpinBox->setSizePolicy(sizePolicy2);

        popupBoxLayout->addWidget(popupWindowTimeoutSpinBox, 3, 1, 1, 1);

        popupOpacitySlider = new QSlider(popupInterfaceGroupBox);
        popupOpacitySlider->setObjectName("popupOpacitySlider");
        popupOpacitySlider->setMaximum(100);
        popupOpacitySlider->setOrientation(Qt::Horizontal);

        popupBoxLayout->addWidget(popupOpacitySlider, 0, 1, 1, 1);


        interfaceLayout->addWidget(popupInterfaceGroupBox);

        languageFormatGroupBox = new QGroupBox(interfacePage);
        languageFormatGroupBox->setObjectName("languageFormatGroupBox");
        formLayout_3 = new QFormLayout(languageFormatGroupBox);
        formLayout_3->setObjectName("formLayout_3");
        mainWindowLanguageFormatLabel = new QLabel(languageFormatGroupBox);
        mainWindowLanguageFormatLabel->setObjectName("mainWindowLanguageFormatLabel");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, mainWindowLanguageFormatLabel);

        mainWindowLanguageFormatComboBox = new QComboBox(languageFormatGroupBox);
        mainWindowLanguageFormatComboBox->addItem(QString());
        mainWindowLanguageFormatComboBox->addItem(QString());
        mainWindowLanguageFormatComboBox->setObjectName("mainWindowLanguageFormatComboBox");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, mainWindowLanguageFormatComboBox);

        popupLanguageFormatLabel = new QLabel(languageFormatGroupBox);
        popupLanguageFormatLabel->setObjectName("popupLanguageFormatLabel");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, popupLanguageFormatLabel);

        popupLanguageFormatComboBox = new QComboBox(languageFormatGroupBox);
        popupLanguageFormatComboBox->addItem(QString());
        popupLanguageFormatComboBox->addItem(QString());
        popupLanguageFormatComboBox->setObjectName("popupLanguageFormatComboBox");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, popupLanguageFormatComboBox);


        interfaceLayout->addWidget(languageFormatGroupBox);

        trayIconGroupBox = new QGroupBox(interfacePage);
        trayIconGroupBox->setObjectName("trayIconGroupBox");
        formLayout_4 = new QFormLayout(trayIconGroupBox);
        formLayout_4->setObjectName("formLayout_4");
        trayIconLabel = new QLabel(trayIconGroupBox);
        trayIconLabel->setObjectName("trayIconLabel");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, trayIconLabel);

        trayIconComboBox = new QComboBox(trayIconGroupBox);
        QIcon icon9(QIcon::fromTheme(QString::fromUtf8("org.kde.CrowTranslate-tray")));
        trayIconComboBox->addItem(icon9, QString());
        QIcon icon10(QIcon::fromTheme(QString::fromUtf8("org.kde.CrowTranslate-tray-light")));
        trayIconComboBox->addItem(icon10, QString());
        QIcon icon11(QIcon::fromTheme(QString::fromUtf8("org.kde.CrowTranslate-tray-dark")));
        trayIconComboBox->addItem(icon11, QString());
        QIcon icon12(QIcon::fromTheme(QString::fromUtf8("folder")));
        trayIconComboBox->addItem(icon12, QString());
        trayIconComboBox->setObjectName("trayIconComboBox");
        sizePolicy2.setHeightForWidth(trayIconComboBox->sizePolicy().hasHeightForWidth());
        trayIconComboBox->setSizePolicy(sizePolicy2);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, trayIconComboBox);

        customTrayIconLabel = new QLabel(trayIconGroupBox);
        customTrayIconLabel->setObjectName("customTrayIconLabel");
        customTrayIconLabel->setEnabled(false);

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, customTrayIconLabel);

        trayIconPathLayout = new QHBoxLayout();
        trayIconPathLayout->setObjectName("trayIconPathLayout");
        customTrayIconEdit = new QLineEdit(trayIconGroupBox);
        customTrayIconEdit->setObjectName("customTrayIconEdit");
        customTrayIconEdit->setEnabled(false);

        trayIconPathLayout->addWidget(customTrayIconEdit);

        customTrayIconButton = new QToolButton(trayIconGroupBox);
        customTrayIconButton->setObjectName("customTrayIconButton");
        customTrayIconButton->setEnabled(false);
        customTrayIconButton->setText(QString::fromUtf8(""));

        trayIconPathLayout->addWidget(customTrayIconButton);


        formLayout_4->setLayout(1, QFormLayout::ItemRole::FieldRole, trayIconPathLayout);


        interfaceLayout->addWidget(trayIconGroupBox);

        interfacePageSpacer = new QSpacerItem(20, 299, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        interfaceLayout->addItem(interfacePageSpacer);

        pagesStackedWidget->addWidget(interfacePage);
        translationPage = new QWidget();
        translationPage->setObjectName("translationPage");
        widget = new QWidget(translationPage);
        widget->setObjectName("widget");
        widget->setGeometry(QRect(0, 0, 611, 591));
        verticalLayout_3 = new QVBoxLayout(widget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        translationProviderLabel = new QLabel(widget);
        translationProviderLabel->setObjectName("translationProviderLabel");

        verticalLayout_3->addWidget(translationProviderLabel);

        translationProviderComboBox = new QComboBox(widget);
        translationProviderComboBox->setObjectName("translationProviderComboBox");

        verticalLayout_3->addWidget(translationProviderComboBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        langDetectionGroupBox = new QGroupBox(widget);
        langDetectionGroupBox->setObjectName("langDetectionGroupBox");
        formLayout_5 = new QFormLayout(langDetectionGroupBox);
        formLayout_5->setObjectName("formLayout_5");
        primaryLangLabel = new QLabel(langDetectionGroupBox);
        primaryLangLabel->setObjectName("primaryLangLabel");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::LabelRole, primaryLangLabel);

        primaryLangComboBox = new QComboBox(langDetectionGroupBox);
        primaryLangComboBox->setObjectName("primaryLangComboBox");

        formLayout_5->setWidget(0, QFormLayout::ItemRole::FieldRole, primaryLangComboBox);

        secondaryLangLabel = new QLabel(langDetectionGroupBox);
        secondaryLangLabel->setObjectName("secondaryLangLabel");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::LabelRole, secondaryLangLabel);

        secondaryLangComboBox = new QComboBox(langDetectionGroupBox);
        secondaryLangComboBox->setObjectName("secondaryLangComboBox");

        formLayout_5->setWidget(1, QFormLayout::ItemRole::FieldRole, secondaryLangComboBox);

        forceSourceAutodetectCheckBox = new QCheckBox(langDetectionGroupBox);
        forceSourceAutodetectCheckBox->setObjectName("forceSourceAutodetectCheckBox");

        formLayout_5->setWidget(2, QFormLayout::ItemRole::SpanningRole, forceSourceAutodetectCheckBox);

        forceTranslationAutodetectCheckBox = new QCheckBox(langDetectionGroupBox);
        forceTranslationAutodetectCheckBox->setObjectName("forceTranslationAutodetectCheckBox");

        formLayout_5->setWidget(3, QFormLayout::ItemRole::SpanningRole, forceTranslationAutodetectCheckBox);


        verticalLayout_3->addWidget(langDetectionGroupBox);

        pagesStackedWidget->addWidget(translationPage);
        ttsPage = new QWidget();
        ttsPage->setObjectName("ttsPage");
        sizePolicy3.setHeightForWidth(ttsPage->sizePolicy().hasHeightForWidth());
        ttsPage->setSizePolicy(sizePolicy3);
        ttsLayout = new QVBoxLayout(ttsPage);
        ttsLayout->setObjectName("ttsLayout");
        ttsGroupBox = new QGroupBox(ttsPage);
        ttsGroupBox->setObjectName("ttsGroupBox");
        ttsFormLayout = new QFormLayout(ttsGroupBox);
        ttsFormLayout->setObjectName("ttsFormLayout");
        ttsProviderLabel = new QLabel(ttsGroupBox);
        ttsProviderLabel->setObjectName("ttsProviderLabel");

        ttsFormLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, ttsProviderLabel);

        ttsProviderComboBox = new QComboBox(ttsGroupBox);
        ttsProviderComboBox->setObjectName("ttsProviderComboBox");

        ttsFormLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, ttsProviderComboBox);


        ttsLayout->addWidget(ttsGroupBox);

        ttsVerticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        ttsLayout->addItem(ttsVerticalSpacer);

        pagesStackedWidget->addWidget(ttsPage);
        mozhiPage = new QWidget();
        mozhiPage->setObjectName("mozhiPage");
        sizePolicy3.setHeightForWidth(mozhiPage->sizePolicy().hasHeightForWidth());
        mozhiPage->setSizePolicy(sizePolicy3);
        translationLayout = new QVBoxLayout(mozhiPage);
        translationLayout->setObjectName("translationLayout");
        translationGroupBox = new QGroupBox(mozhiPage);
        translationGroupBox->setObjectName("translationGroupBox");
        translationBoxLayout = new QVBoxLayout(translationGroupBox);
        translationBoxLayout->setObjectName("translationBoxLayout");
        sourceTranslitCheckBox = new QCheckBox(translationGroupBox);
        sourceTranslitCheckBox->setObjectName("sourceTranslitCheckBox");

        translationBoxLayout->addWidget(sourceTranslitCheckBox);

        translationTranslitCheckBox = new QCheckBox(translationGroupBox);
        translationTranslitCheckBox->setObjectName("translationTranslitCheckBox");

        translationBoxLayout->addWidget(translationTranslitCheckBox);

        sourceTranscriptionCheckBox = new QCheckBox(translationGroupBox);
        sourceTranscriptionCheckBox->setObjectName("sourceTranscriptionCheckBox");

        translationBoxLayout->addWidget(sourceTranscriptionCheckBox);

        translationOptionsCheckBox = new QCheckBox(translationGroupBox);
        translationOptionsCheckBox->setObjectName("translationOptionsCheckBox");

        translationBoxLayout->addWidget(translationOptionsCheckBox);

        examplesCheckBox = new QCheckBox(translationGroupBox);
        examplesCheckBox->setObjectName("examplesCheckBox");

        translationBoxLayout->addWidget(examplesCheckBox);

        sourceSimplificationCheckBox = new QCheckBox(translationGroupBox);
        sourceSimplificationCheckBox->setObjectName("sourceSimplificationCheckBox");

        translationBoxLayout->addWidget(sourceSimplificationCheckBox);


        translationLayout->addWidget(translationGroupBox);

        mozhiGroupBox = new QGroupBox(mozhiPage);
        mozhiGroupBox->setObjectName("mozhiGroupBox");
        mozhiGroupBox->setTitle(QString::fromUtf8("Mozhi"));
        horizontalLayout = new QHBoxLayout(mozhiGroupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        mozhiUrlLabel = new QLabel(mozhiGroupBox);
        mozhiUrlLabel->setObjectName("mozhiUrlLabel");
        mozhiUrlLabel->setText(QString::fromUtf8("URL:"));

        horizontalLayout->addWidget(mozhiUrlLabel);

        mozhiUrlComboBox = new QComboBox(mozhiGroupBox);
        mozhiUrlComboBox->setObjectName("mozhiUrlComboBox");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(mozhiUrlComboBox->sizePolicy().hasHeightForWidth());
        mozhiUrlComboBox->setSizePolicy(sizePolicy4);
        mozhiUrlComboBox->setEditable(true);
        mozhiUrlComboBox->setCurrentText(QString::fromUtf8(""));

        horizontalLayout->addWidget(mozhiUrlComboBox);

        detectFastestButton = new QPushButton(mozhiGroupBox);
        detectFastestButton->setObjectName("detectFastestButton");

        horizontalLayout->addWidget(detectFastestButton);


        translationLayout->addWidget(mozhiGroupBox);

        translationPageSpacer = new QSpacerItem(20, 182, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        translationLayout->addItem(translationPageSpacer);

        pagesStackedWidget->addWidget(mozhiPage);
        ocrPage = new QWidget();
        ocrPage->setObjectName("ocrPage");
        sizePolicy3.setHeightForWidth(ocrPage->sizePolicy().hasHeightForWidth());
        ocrPage->setSizePolicy(sizePolicy3);
        ocrLayout = new QVBoxLayout(ocrPage);
        ocrLayout->setObjectName("ocrLayout");
        languagesGroupBox = new QGroupBox(ocrPage);
        languagesGroupBox->setObjectName("languagesGroupBox");
        ocrLanguagesLayout = new QGridLayout(languagesGroupBox);
        ocrLanguagesLayout->setObjectName("ocrLanguagesLayout");
        ocrLanguagesListWidget = new OcrLanguagesListWidget(languagesGroupBox);
        ocrLanguagesListWidget->setObjectName("ocrLanguagesListWidget");

        ocrLanguagesLayout->addWidget(ocrLanguagesListWidget, 1, 0, 1, 3);

        ocrLanguagesPathLabel = new QLabel(languagesGroupBox);
        ocrLanguagesPathLabel->setObjectName("ocrLanguagesPathLabel");

        ocrLanguagesLayout->addWidget(ocrLanguagesPathLabel, 0, 0, 1, 1);

        ocrLanguagesPathButton = new QToolButton(languagesGroupBox);
        ocrLanguagesPathButton->setObjectName("ocrLanguagesPathButton");
        ocrLanguagesPathButton->setIcon(icon12);

        ocrLanguagesLayout->addWidget(ocrLanguagesPathButton, 0, 2, 1, 1);

        downloadMoreLabel = new QLabel(languagesGroupBox);
        downloadMoreLabel->setObjectName("downloadMoreLabel");
        downloadMoreLabel->setOpenExternalLinks(true);

        ocrLanguagesLayout->addWidget(downloadMoreLabel, 2, 0, 1, 1);

        ocrLanguagesPathEdit = new QLineEdit(languagesGroupBox);
        ocrLanguagesPathEdit->setObjectName("ocrLanguagesPathEdit");

        ocrLanguagesLayout->addWidget(ocrLanguagesPathEdit, 0, 1, 1, 1);


        ocrLayout->addWidget(languagesGroupBox);

        ocrParametersGroupBox = new QGroupBox(ocrPage);
        ocrParametersGroupBox->setObjectName("ocrParametersGroupBox");
        ocrParametersGroupBox->setTitle(QString::fromUtf8("OCR"));
        ocrParametersLayout = new QVBoxLayout(ocrParametersGroupBox);
        ocrParametersLayout->setObjectName("ocrParametersLayout");
        convertLineBreaksCheckBox = new QCheckBox(ocrParametersGroupBox);
        convertLineBreaksCheckBox->setObjectName("convertLineBreaksCheckBox");

        ocrParametersLayout->addWidget(convertLineBreaksCheckBox);

        tesseractParametersTableHorizontalLayout = new QHBoxLayout();
        tesseractParametersTableHorizontalLayout->setObjectName("tesseractParametersTableHorizontalLayout");
        tesseractParametersButtonsVerticalLayout = new QVBoxLayout();
        tesseractParametersButtonsVerticalLayout->setObjectName("tesseractParametersButtonsVerticalLayout");
        tesseractParametersButtonsVerticalSpacer1 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        tesseractParametersButtonsVerticalLayout->addItem(tesseractParametersButtonsVerticalSpacer1);

        tesseractParametersAddButton = new QToolButton(ocrParametersGroupBox);
        tesseractParametersAddButton->setObjectName("tesseractParametersAddButton");
        QIcon icon13(QIcon::fromTheme(QString::fromUtf8("list-add")));
        tesseractParametersAddButton->setIcon(icon13);

        tesseractParametersButtonsVerticalLayout->addWidget(tesseractParametersAddButton);

        tesseractParametersRemoveButton = new QToolButton(ocrParametersGroupBox);
        tesseractParametersRemoveButton->setObjectName("tesseractParametersRemoveButton");
        tesseractParametersRemoveButton->setEnabled(false);
        QIcon icon14(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        tesseractParametersRemoveButton->setIcon(icon14);

        tesseractParametersButtonsVerticalLayout->addWidget(tesseractParametersRemoveButton);

        tesseractParametersButtonsVerticalSpacer2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        tesseractParametersButtonsVerticalLayout->addItem(tesseractParametersButtonsVerticalSpacer2);


        tesseractParametersTableHorizontalLayout->addLayout(tesseractParametersButtonsVerticalLayout);

        tesseractParametersTableWidget = new TesseractParametersTableWidget(ocrParametersGroupBox);
        tesseractParametersTableWidget->setObjectName("tesseractParametersTableWidget");

        tesseractParametersTableHorizontalLayout->addWidget(tesseractParametersTableWidget);


        ocrParametersLayout->addLayout(tesseractParametersTableHorizontalLayout);


        ocrLayout->addWidget(ocrParametersGroupBox);

        screenCaptureGroupBox = new QGroupBox(ocrPage);
        screenCaptureGroupBox->setObjectName("screenCaptureGroupBox");
        gridLayout = new QGridLayout(screenCaptureGroupBox);
        gridLayout->setObjectName("gridLayout");
        rememverRegionLabel = new QLabel(screenCaptureGroupBox);
        rememverRegionLabel->setObjectName("rememverRegionLabel");
        sizePolicy1.setHeightForWidth(rememverRegionLabel->sizePolicy().hasHeightForWidth());
        rememverRegionLabel->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(rememverRegionLabel, 0, 0, 1, 1);

        rememberRegionComboBox = new QComboBox(screenCaptureGroupBox);
        rememberRegionComboBox->addItem(QString());
        rememberRegionComboBox->addItem(QString());
        rememberRegionComboBox->addItem(QString());
        rememberRegionComboBox->setObjectName("rememberRegionComboBox");

        gridLayout->addWidget(rememberRegionComboBox, 0, 1, 1, 2);

        captureDelayLabel = new QLabel(screenCaptureGroupBox);
        captureDelayLabel->setObjectName("captureDelayLabel");

        gridLayout->addWidget(captureDelayLabel, 1, 0, 1, 1);

        captureDelaySpinBox = new QSpinBox(screenCaptureGroupBox);
        captureDelaySpinBox->setObjectName("captureDelaySpinBox");
        captureDelaySpinBox->setMaximum(10000);

        gridLayout->addWidget(captureDelaySpinBox, 1, 1, 1, 2);

        showMagnifierCheckBox = new QCheckBox(screenCaptureGroupBox);
        showMagnifierCheckBox->setObjectName("showMagnifierCheckBox");

        gridLayout->addWidget(showMagnifierCheckBox, 2, 0, 1, 1);

        negateOcrCheckBox = new QCheckBox(screenCaptureGroupBox);
        negateOcrCheckBox->setObjectName("negateOcrCheckBox");

        gridLayout->addWidget(negateOcrCheckBox, 2, 2, 1, 1);

        confirmOnReleaseCheckBox = new QCheckBox(screenCaptureGroupBox);
        confirmOnReleaseCheckBox->setObjectName("confirmOnReleaseCheckBox");
        confirmOnReleaseCheckBox->setEnabled(true);

        gridLayout->addWidget(confirmOnReleaseCheckBox, 3, 0, 1, 2);

        applyLightMaskCheckBox = new QCheckBox(screenCaptureGroupBox);
        applyLightMaskCheckBox->setObjectName("applyLightMaskCheckBox");

        gridLayout->addWidget(applyLightMaskCheckBox, 4, 0, 1, 2);


        ocrLayout->addWidget(screenCaptureGroupBox);

        ocrSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        ocrLayout->addItem(ocrSpacer);

        pagesStackedWidget->addWidget(ocrPage);
        connectionPage = new QWidget();
        connectionPage->setObjectName("connectionPage");
        sizePolicy3.setHeightForWidth(connectionPage->sizePolicy().hasHeightForWidth());
        connectionPage->setSizePolicy(sizePolicy3);
        connectionLayout = new QVBoxLayout(connectionPage);
        connectionLayout->setObjectName("connectionLayout");
        proxyGroupBox = new QGroupBox(connectionPage);
        proxyGroupBox->setObjectName("proxyGroupBox");
        formLayout_8 = new QFormLayout(proxyGroupBox);
        formLayout_8->setObjectName("formLayout_8");
        proxyTypeLabel = new QLabel(proxyGroupBox);
        proxyTypeLabel->setObjectName("proxyTypeLabel");

        formLayout_8->setWidget(0, QFormLayout::ItemRole::LabelRole, proxyTypeLabel);

        proxyTypeComboBox = new QComboBox(proxyGroupBox);
        proxyTypeComboBox->addItem(QString());
        proxyTypeComboBox->addItem(QString::fromUtf8("SOCKS5"));
        proxyTypeComboBox->addItem(QString());
        proxyTypeComboBox->addItem(QString::fromUtf8("HTTP"));
        proxyTypeComboBox->setObjectName("proxyTypeComboBox");
        sizePolicy2.setHeightForWidth(proxyTypeComboBox->sizePolicy().hasHeightForWidth());
        proxyTypeComboBox->setSizePolicy(sizePolicy2);

        formLayout_8->setWidget(0, QFormLayout::ItemRole::FieldRole, proxyTypeComboBox);

        proxyHostLabel = new QLabel(proxyGroupBox);
        proxyHostLabel->setObjectName("proxyHostLabel");
        proxyHostLabel->setEnabled(false);

        formLayout_8->setWidget(1, QFormLayout::ItemRole::LabelRole, proxyHostLabel);

        proxyHostEdit = new QLineEdit(proxyGroupBox);
        proxyHostEdit->setObjectName("proxyHostEdit");
        proxyHostEdit->setEnabled(false);

        formLayout_8->setWidget(1, QFormLayout::ItemRole::FieldRole, proxyHostEdit);

        proxyPortLabel = new QLabel(proxyGroupBox);
        proxyPortLabel->setObjectName("proxyPortLabel");
        proxyPortLabel->setEnabled(false);

        formLayout_8->setWidget(2, QFormLayout::ItemRole::LabelRole, proxyPortLabel);

        proxyPortSpinbox = new QSpinBox(proxyGroupBox);
        proxyPortSpinbox->setObjectName("proxyPortSpinbox");
        proxyPortSpinbox->setEnabled(false);
        sizePolicy2.setHeightForWidth(proxyPortSpinbox->sizePolicy().hasHeightForWidth());
        proxyPortSpinbox->setSizePolicy(sizePolicy2);
        proxyPortSpinbox->setMinimum(1);
        proxyPortSpinbox->setMaximum(65535);
        proxyPortSpinbox->setValue(8080);

        formLayout_8->setWidget(2, QFormLayout::ItemRole::FieldRole, proxyPortSpinbox);

        proxyInfoLabel = new QLabel(proxyGroupBox);
        proxyInfoLabel->setObjectName("proxyInfoLabel");
        proxyInfoLabel->setEnabled(false);

        formLayout_8->setWidget(3, QFormLayout::ItemRole::SpanningRole, proxyInfoLabel);

        proxyAuthCheckBox = new QCheckBox(proxyGroupBox);
        proxyAuthCheckBox->setObjectName("proxyAuthCheckBox");
        proxyAuthCheckBox->setEnabled(false);

        formLayout_8->setWidget(4, QFormLayout::ItemRole::SpanningRole, proxyAuthCheckBox);

        proxyUsernameLabel = new QLabel(proxyGroupBox);
        proxyUsernameLabel->setObjectName("proxyUsernameLabel");
        proxyUsernameLabel->setEnabled(false);

        formLayout_8->setWidget(5, QFormLayout::ItemRole::LabelRole, proxyUsernameLabel);

        proxyUsernameEdit = new QLineEdit(proxyGroupBox);
        proxyUsernameEdit->setObjectName("proxyUsernameEdit");
        proxyUsernameEdit->setEnabled(false);

        formLayout_8->setWidget(5, QFormLayout::ItemRole::FieldRole, proxyUsernameEdit);

        proxyPasswordLabel = new QLabel(proxyGroupBox);
        proxyPasswordLabel->setObjectName("proxyPasswordLabel");
        proxyPasswordLabel->setEnabled(false);

        formLayout_8->setWidget(6, QFormLayout::ItemRole::LabelRole, proxyPasswordLabel);

        proxyPasswordEdit = new QLineEdit(proxyGroupBox);
        proxyPasswordEdit->setObjectName("proxyPasswordEdit");
        proxyPasswordEdit->setEnabled(false);
        proxyPasswordEdit->setEchoMode(QLineEdit::Password);

        formLayout_8->setWidget(6, QFormLayout::ItemRole::FieldRole, proxyPasswordEdit);

        proxyPasswordInfoLabel = new QLabel(proxyGroupBox);
        proxyPasswordInfoLabel->setObjectName("proxyPasswordInfoLabel");
        proxyPasswordInfoLabel->setEnabled(false);

        formLayout_8->setWidget(7, QFormLayout::ItemRole::SpanningRole, proxyPasswordInfoLabel);


        connectionLayout->addWidget(proxyGroupBox);

        proxyPageSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        connectionLayout->addItem(proxyPageSpacer);

        pagesStackedWidget->addWidget(connectionPage);
        shortcutsPage = new QWidget();
        shortcutsPage->setObjectName("shortcutsPage");
        sizePolicy3.setHeightForWidth(shortcutsPage->sizePolicy().hasHeightForWidth());
        shortcutsPage->setSizePolicy(sizePolicy3);
        shortcutsLayout = new QVBoxLayout(shortcutsPage);
        shortcutsLayout->setObjectName("shortcutsLayout");
        shortcutsTreeView = new ShortcutsView(shortcutsPage);
        shortcutsTreeView->setObjectName("shortcutsTreeView");

        shortcutsLayout->addWidget(shortcutsTreeView);

        globalShortcutsCheckBox = new QCheckBox(shortcutsPage);
        globalShortcutsCheckBox->setObjectName("globalShortcutsCheckBox");
        globalShortcutsCheckBox->setChecked(true);

        shortcutsLayout->addWidget(globalShortcutsCheckBox);

        resetAllShortcutsButton = new QPushButton(shortcutsPage);
        resetAllShortcutsButton->setObjectName("resetAllShortcutsButton");
        sizePolicy2.setHeightForWidth(resetAllShortcutsButton->sizePolicy().hasHeightForWidth());
        resetAllShortcutsButton->setSizePolicy(sizePolicy2);

        shortcutsLayout->addWidget(resetAllShortcutsButton);

        shortcutGroupBox = new QGroupBox(shortcutsPage);
        shortcutGroupBox->setObjectName("shortcutGroupBox");
        shortcutGroupBox->setEnabled(false);
        shortcutBoxLayout = new QHBoxLayout(shortcutGroupBox);
        shortcutBoxLayout->setObjectName("shortcutBoxLayout");
        shortcutLabel = new QLabel(shortcutGroupBox);
        shortcutLabel->setObjectName("shortcutLabel");

        shortcutBoxLayout->addWidget(shortcutLabel);

        shortcutSequenceEdit = new QKeySequenceEdit(shortcutGroupBox);
        shortcutSequenceEdit->setObjectName("shortcutSequenceEdit");

        shortcutBoxLayout->addWidget(shortcutSequenceEdit);

        acceptShortcutButton = new QToolButton(shortcutGroupBox);
        acceptShortcutButton->setObjectName("acceptShortcutButton");
        QIcon icon15(QIcon::fromTheme(QString::fromUtf8("dialog-ok-apply")));
        acceptShortcutButton->setIcon(icon15);

        shortcutBoxLayout->addWidget(acceptShortcutButton);

        clearShortcutButton = new QToolButton(shortcutGroupBox);
        clearShortcutButton->setObjectName("clearShortcutButton");
        QIcon icon16(QIcon::fromTheme(QString::fromUtf8("edit-clear-all")));
        clearShortcutButton->setIcon(icon16);

        shortcutBoxLayout->addWidget(clearShortcutButton);

        resetShortcutButton = new QToolButton(shortcutGroupBox);
        resetShortcutButton->setObjectName("resetShortcutButton");
        QIcon icon17(QIcon::fromTheme(QString::fromUtf8("view-refresh")));
        resetShortcutButton->setIcon(icon17);

        shortcutBoxLayout->addWidget(resetShortcutButton);


        shortcutsLayout->addWidget(shortcutGroupBox);

        pagesStackedWidget->addWidget(shortcutsPage);
        aboutPage = new QWidget();
        aboutPage->setObjectName("aboutPage");
        sizePolicy3.setHeightForWidth(aboutPage->sizePolicy().hasHeightForWidth());
        aboutPage->setSizePolicy(sizePolicy3);
        verticalLayout = new QVBoxLayout(aboutPage);
        verticalLayout->setObjectName("verticalLayout");
        logoLabel = new QLabel(aboutPage);
        logoLabel->setObjectName("logoLabel");
        logoLabel->setMaximumSize(QSize(200, 200));
        logoLabel->setScaledContents(true);
        logoLabel->setMargin(20);

        verticalLayout->addWidget(logoLabel);

        aboutGroupBox = new QGroupBox(aboutPage);
        aboutGroupBox->setObjectName("aboutGroupBox");
        aboutGroupBox->setTitle(QString::fromUtf8("Crow Translate"));
        formLayout_9 = new QFormLayout(aboutGroupBox);
        formLayout_9->setObjectName("formLayout_9");
        versionTitleLabel = new QLabel(aboutGroupBox);
        versionTitleLabel->setObjectName("versionTitleLabel");

        formLayout_9->setWidget(0, QFormLayout::ItemRole::LabelRole, versionTitleLabel);

        versionLabel = new QLabel(aboutGroupBox);
        versionLabel->setObjectName("versionLabel");

        formLayout_9->setWidget(0, QFormLayout::ItemRole::FieldRole, versionLabel);

        licenseTitleLabel = new QLabel(aboutGroupBox);
        licenseTitleLabel->setObjectName("licenseTitleLabel");

        formLayout_9->setWidget(1, QFormLayout::ItemRole::LabelRole, licenseTitleLabel);

        licenseLabel = new QLabel(aboutGroupBox);
        licenseLabel->setObjectName("licenseLabel");
        licenseLabel->setText(QString::fromUtf8("GPL v3 "));

        formLayout_9->setWidget(1, QFormLayout::ItemRole::FieldRole, licenseLabel);

        sourceTitleLabel = new QLabel(aboutGroupBox);
        sourceTitleLabel->setObjectName("sourceTitleLabel");

        formLayout_9->setWidget(2, QFormLayout::ItemRole::LabelRole, sourceTitleLabel);

        sourceLabel = new QLabel(aboutGroupBox);
        sourceLabel->setObjectName("sourceLabel");
        sourceLabel->setText(QString::fromUtf8("<html><head/><body><p><a href=\"https://invent.kde.org/office/crow-translate/\">crow-translate</a></p></body></html>"));
        sourceLabel->setOpenExternalLinks(true);
        sourceLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_9->setWidget(2, QFormLayout::ItemRole::FieldRole, sourceLabel);

        backendTitleLabel = new QLabel(aboutGroupBox);
        backendTitleLabel->setObjectName("backendTitleLabel");

        formLayout_9->setWidget(3, QFormLayout::ItemRole::LabelRole, backendTitleLabel);

        backendLabel = new QLabel(aboutGroupBox);
        backendLabel->setObjectName("backendLabel");
        backendLabel->setText(QString::fromUtf8("<html><head/><body><p><a href=\"https://codeberg.org/aryak/mozhi\">Mozhi</a></p></body></html>"));
        backendLabel->setOpenExternalLinks(true);
        backendLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout_9->setWidget(3, QFormLayout::ItemRole::FieldRole, backendLabel);


        verticalLayout->addWidget(aboutGroupBox);

        aboutPageVerticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(aboutPageVerticalSpacer);

        pagesStackedWidget->addWidget(aboutPage);

        verticalLayout_2->addWidget(pagesStackedWidget);

        scrollArea->setWidget(scrollAreaWidgetContents);
        splitter->addWidget(scrollArea);

        settingsDialogLayout->addWidget(splitter);

        dialogButtonBox = new QDialogButtonBox(SettingsDialog);
        dialogButtonBox->setObjectName("dialogButtonBox");
        dialogButtonBox->setOrientation(Qt::Horizontal);
        dialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::RestoreDefaults);

        settingsDialogLayout->addWidget(dialogButtonBox);


        retranslateUi(SettingsDialog);
        QObject::connect(dialogButtonBox, &QDialogButtonBox::accepted, SettingsDialog, qOverload<>(&QDialog::accept));
        QObject::connect(dialogButtonBox, &QDialogButtonBox::rejected, SettingsDialog, qOverload<>(&QDialog::reject));
        QObject::connect(pagesListWidget, SIGNAL(currentRowChanged(int)), SettingsDialog, SLOT(setCurrentPage(int)));
        QObject::connect(popupOpacitySlider, &QSlider::valueChanged, popupOpacitySpinBox, &QSpinBox::setValue);
        QObject::connect(popupOpacitySpinBox, &QSpinBox::valueChanged, popupOpacitySlider, &QSlider::setValue);
        QObject::connect(popupWidthSlider, &QSlider::valueChanged, popupWidthSpinBox, &QSpinBox::setValue);
        QObject::connect(popupWidthSpinBox, &QSpinBox::valueChanged, popupWidthSlider, &QSlider::setValue);
        QObject::connect(popupHeightSlider, &QSlider::valueChanged, popupHeightSpinBox, &QSpinBox::setValue);
        QObject::connect(popupHeightSpinBox, &QSpinBox::valueChanged, popupHeightSlider, &QSlider::setValue);
        QObject::connect(proxyAuthCheckBox, &QCheckBox::toggled, proxyUsernameEdit, &QLineEdit::setEnabled);
        QObject::connect(proxyAuthCheckBox, &QCheckBox::toggled, proxyUsernameLabel, &QLabel::setEnabled);
        QObject::connect(proxyAuthCheckBox, &QCheckBox::toggled, proxyPasswordLabel, &QLabel::setEnabled);
        QObject::connect(proxyAuthCheckBox, &QCheckBox::toggled, proxyPasswordEdit, &QLineEdit::setEnabled);
        QObject::connect(proxyAuthCheckBox, &QCheckBox::toggled, proxyPasswordInfoLabel, &QLabel::setEnabled);
        QObject::connect(showTrayIconCheckBox, &QCheckBox::toggled, startMinimizedCheckBox, &QCheckBox::setEnabled);
        QObject::connect(showTrayIconCheckBox, &QCheckBox::toggled, startMinimizedCheckBox, &QCheckBox::setChecked);
        QObject::connect(proxyTypeComboBox, SIGNAL(currentIndexChanged(int)), SettingsDialog, SLOT(onProxyTypeChanged(int)));
        QObject::connect(trayIconComboBox, SIGNAL(currentIndexChanged(int)), SettingsDialog, SLOT(onTrayIconTypeChanged(int)));
        QObject::connect(customTrayIconButton, SIGNAL(clicked()), SettingsDialog, SLOT(selectCustomTrayIcon()));
        QObject::connect(customTrayIconEdit, SIGNAL(textChanged(QString)), SettingsDialog, SLOT(setCustomTrayIconPreview(QString)));
        QObject::connect(resetAllShortcutsButton, SIGNAL(clicked()), SettingsDialog, SLOT(resetAllShortcuts()));
        QObject::connect(resetShortcutButton, SIGNAL(clicked()), SettingsDialog, SLOT(resetCurrentShortcut()));
        QObject::connect(acceptShortcutButton, SIGNAL(clicked()), SettingsDialog, SLOT(acceptCurrentShortcut()));
        QObject::connect(clearShortcutButton, SIGNAL(clicked()), SettingsDialog, SLOT(clearCurrentShortcut()));
        QObject::connect(shortcutSequenceEdit, SIGNAL(editingFinished()), SettingsDialog, SLOT(updateAcceptButton()));
        QObject::connect(shortcutsTreeView, SIGNAL(currentItemChanged(ShortcutItem*)), SettingsDialog, SLOT(loadShortcut(ShortcutItem*)));
        QObject::connect(ocrLanguagesPathButton, SIGNAL(clicked()), SettingsDialog, SLOT(selectOcrLanguagesPath()));
        QObject::connect(ocrLanguagesPathEdit, SIGNAL(textChanged(QString)), SettingsDialog, SLOT(onOcrLanguagesPathChanged(QString)));
        QObject::connect(windowModeComboBox, SIGNAL(currentIndexChanged(int)), SettingsDialog, SLOT(onWindowModeChanged(int)));
        QObject::connect(tesseractParametersAddButton, &QToolButton::clicked, tesseractParametersTableWidget, qOverload<>(&TesseractParametersTableWidget::addDefaultParam));
        QObject::connect(tesseractParametersRemoveButton, &QToolButton::clicked, tesseractParametersTableWidget, qOverload<>(&TesseractParametersTableWidget::removeCurrent));
        QObject::connect(tesseractParametersTableWidget, SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)), SettingsDialog, SLOT(onTesseractParametersCurrentItemChanged()));
        QObject::connect(detectFastestButton, SIGNAL(clicked()), SettingsDialog, SLOT(detectFastestInstance()));

        pagesListWidget->setCurrentRow(-1);
        pagesStackedWidget->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(SettingsDialog);
    } // setupUi

    void retranslateUi(QDialog *SettingsDialog)
    {
        SettingsDialog->setWindowTitle(QCoreApplication::translate("SettingsDialog", "Settings", nullptr));

        const bool __sortingEnabled = pagesListWidget->isSortingEnabled();
        pagesListWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = pagesListWidget->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("SettingsDialog", "General", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = pagesListWidget->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("SettingsDialog", "Interface", nullptr));
        QListWidgetItem *___qlistwidgetitem2 = pagesListWidget->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("SettingsDialog", "Translation", nullptr));
        QListWidgetItem *___qlistwidgetitem3 = pagesListWidget->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("SettingsDialog", "Text-To-Speech", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = pagesListWidget->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("SettingsDialog", "Mozhi", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = pagesListWidget->item(6);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("SettingsDialog", "Connection", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = pagesListWidget->item(7);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("SettingsDialog", "Shortcuts", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = pagesListWidget->item(8);
        ___qlistwidgetitem7->setText(QCoreApplication::translate("SettingsDialog", "About", nullptr));
        pagesListWidget->setSortingEnabled(__sortingEnabled);

        generalGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "General", nullptr));
        localeLabel->setText(QCoreApplication::translate("SettingsDialog", "Language:", nullptr));
#if QT_CONFIG(tooltip)
        localeComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Interface language</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        mainWindowOrientationLabel->setText(QCoreApplication::translate("SettingsDialog", "Main window orientation:", nullptr));
        mainWindowOrientationComboBox->setItemText(0, QCoreApplication::translate("SettingsDialog", "Auto", nullptr));
        mainWindowOrientationComboBox->setItemText(1, QCoreApplication::translate("SettingsDialog", "Portrait", nullptr));
        mainWindowOrientationComboBox->setItemText(2, QCoreApplication::translate("SettingsDialog", "Landscape", nullptr));

#if QT_CONFIG(tooltip)
        mainWindowOrientationComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Orientation of the main window layout<br/>When using <span style=\" font-style:italic;\">Auto</span>, the window orientation will match the screen orientation</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        windowModeLabel->setText(QCoreApplication::translate("SettingsDialog", "Translation mode:", nullptr));
        windowModeComboBox->setItemText(0, QCoreApplication::translate("SettingsDialog", "Pop-up window", nullptr));
        windowModeComboBox->setItemText(1, QCoreApplication::translate("SettingsDialog", "Main window", nullptr));
        windowModeComboBox->setItemText(2, QCoreApplication::translate("SettingsDialog", "Notification", nullptr));

#if QT_CONFIG(tooltip)
        windowModeComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>A window for translating selected text. If the application is minimized, the main window will always be used.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        translationNotificationTimeoutLabel->setText(QCoreApplication::translate("SettingsDialog", "Translation notification timeout:", nullptr));
#if QT_CONFIG(tooltip)
        translationNotificationTimeoutSpinBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Notification with translation display time</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        translationNotificationTimeoutSpinBox->setSuffix(QCoreApplication::translate("SettingsDialog", " sec", nullptr));
#if QT_CONFIG(tooltip)
        showTrayIconCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Display icon in the system tray</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        showTrayIconCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Show tray icon", nullptr));
#if QT_CONFIG(tooltip)
        startMinimizedCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Start application minimized to the system tray</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        startMinimizedCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Start minimized", nullptr));
#if QT_CONFIG(tooltip)
        autostartCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Run the application at system startup</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        autostartCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Launch at startup", nullptr));
        fontGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Font", nullptr));
        fontNameLabel->setText(QCoreApplication::translate("SettingsDialog", "Name:", nullptr));
#if QT_CONFIG(tooltip)
        fontNameComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Translation and source text font</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        fontSizeLabel->setText(QCoreApplication::translate("SettingsDialog", "Size:", nullptr));
#if QT_CONFIG(tooltip)
        fontSizeSpinBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Font size of translation and source text</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        popupInterfaceGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Pop-up window", nullptr));
#if QT_CONFIG(tooltip)
        popupHeightSpinBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Pop-up window height in pixels</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        popupWidthLabel->setText(QCoreApplication::translate("SettingsDialog", "Width:", nullptr));
#if QT_CONFIG(tooltip)
        popupWidthSpinBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Pop-up window width in pixels</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        popupOpacitySpinBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Pop-up window opacity</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        popupOpacityLabel->setText(QCoreApplication::translate("SettingsDialog", "Opacity:", nullptr));
        popupWindowTimeoutLabel->setText(QCoreApplication::translate("SettingsDialog", "Show timeout:", nullptr));
        popupHeightLabel->setText(QCoreApplication::translate("SettingsDialog", "Height:", nullptr));
#if QT_CONFIG(tooltip)
        popupWindowTimeoutSpinBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>The number of seconds after which the window will be hidden if it has no focus</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        popupWindowTimeoutSpinBox->setSuffix(QCoreApplication::translate("SettingsDialog", " sec", nullptr));
        languageFormatGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Language format", nullptr));
        mainWindowLanguageFormatLabel->setText(QCoreApplication::translate("SettingsDialog", "Main window:", nullptr));
        mainWindowLanguageFormatComboBox->setItemText(0, QCoreApplication::translate("SettingsDialog", "Full name", nullptr));
        mainWindowLanguageFormatComboBox->setItemText(1, QCoreApplication::translate("SettingsDialog", "ISO 639-1 code", nullptr));

#if QT_CONFIG(tooltip)
        mainWindowLanguageFormatComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Languages text on buttons</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        popupLanguageFormatLabel->setText(QCoreApplication::translate("SettingsDialog", "Pop-up:", nullptr));
        popupLanguageFormatComboBox->setItemText(0, QCoreApplication::translate("SettingsDialog", "Full name", nullptr));
        popupLanguageFormatComboBox->setItemText(1, QCoreApplication::translate("SettingsDialog", "ISO 639-1 code", nullptr));

#if QT_CONFIG(tooltip)
        popupLanguageFormatComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Languages text on buttons</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        trayIconGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Tray icon", nullptr));
        trayIconLabel->setText(QCoreApplication::translate("SettingsDialog", "Icon:", nullptr));
        trayIconComboBox->setItemText(0, QCoreApplication::translate("SettingsDialog", "Default", nullptr));
        trayIconComboBox->setItemText(1, QCoreApplication::translate("SettingsDialog", "Monochrome (dark theme)", nullptr));
        trayIconComboBox->setItemText(2, QCoreApplication::translate("SettingsDialog", "Monochrome (light theme)", nullptr));
        trayIconComboBox->setItemText(3, QCoreApplication::translate("SettingsDialog", "Custom", nullptr));

#if QT_CONFIG(tooltip)
        trayIconComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>System tray icon</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        customTrayIconLabel->setText(QCoreApplication::translate("SettingsDialog", "Custom:", nullptr));
        customTrayIconEdit->setPlaceholderText(QCoreApplication::translate("SettingsDialog", "Path to the icon or icon name from theme", nullptr));
#if QT_CONFIG(tooltip)
        customTrayIconButton->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Select icon</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        translationProviderLabel->setText(QCoreApplication::translate("SettingsDialog", "Translation provider:", nullptr));
        langDetectionGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Automatic language detection", nullptr));
        primaryLangLabel->setText(QCoreApplication::translate("SettingsDialog", "Primary translation language:", nullptr));
#if QT_CONFIG(tooltip)
        primaryLangComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Language to which text will be translated when autodetecting</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        secondaryLangLabel->setText(QCoreApplication::translate("SettingsDialog", "Secondary translation language:", nullptr));
#if QT_CONFIG(tooltip)
        secondaryLangComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Language to which the text will be translated if it is in the language selected above</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        forceSourceAutodetectCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Automatically switch to <span style=\" font-style:italic;\">Auto</span> when using OCR and global shortcuts</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        forceSourceAutodetectCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Force source language detection", nullptr));
#if QT_CONFIG(tooltip)
        forceTranslationAutodetectCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Automatically switch to <span style=\" font-style:italic;\">Auto</span> when using OCR and global shortcuts</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        forceTranslationAutodetectCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Force translation language detection", nullptr));
        ttsGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Text-to-Speech", nullptr));
        ttsProviderLabel->setText(QCoreApplication::translate("SettingsDialog", "Provider:", nullptr));
        translationGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Translation", nullptr));
#if QT_CONFIG(tooltip)
        sourceTranslitCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Enable or disable source transliteration</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        sourceTranslitCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Enable source transliteration", nullptr));
#if QT_CONFIG(tooltip)
        translationTranslitCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Enable or disable translation transliteration</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        translationTranslitCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Enable translation transliteration", nullptr));
#if QT_CONFIG(tooltip)
        sourceTranscriptionCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Enable or disable source transcription</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        sourceTranscriptionCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Enable source transcription", nullptr));
#if QT_CONFIG(tooltip)
        translationOptionsCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Enable or disable translation options</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        translationOptionsCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Enable translation options", nullptr));
#if QT_CONFIG(tooltip)
        examplesCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Enable or disable usage examples</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        examplesCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Enable examples", nullptr));
#if QT_CONFIG(tooltip)
        sourceSimplificationCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Replace each sequence of whitespaces (this includes the ASCII characters '\\t', '\\n', '\\v', '\\f', '\\r', and ' ') with a single space in queries</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        sourceSimplificationCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Simplify source", nullptr));
#if QT_CONFIG(tooltip)
        mozhiUrlComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "Mozhi instance URL", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        detectFastestButton->setToolTip(QCoreApplication::translate("SettingsDialog", "Automatically pick the fastest instance based on the ping", nullptr));
#endif // QT_CONFIG(tooltip)
        detectFastestButton->setText(QCoreApplication::translate("SettingsDialog", "Detect fastest", nullptr));
        languagesGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Languages", nullptr));
#if QT_CONFIG(tooltip)
        ocrLanguagesListWidget->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Loading additional languages will impact both speed and accuracy, as there is more work to do to decide on the applicable language, and there is more chance of hallucinating incorrect words.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        ocrLanguagesPathLabel->setText(QCoreApplication::translate("SettingsDialog", "Languages path:", nullptr));
#if QT_CONFIG(tooltip)
        ocrLanguagesPathButton->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Select OCR languages path</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        downloadMoreLabel->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Open GitHub repository</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        downloadMoreLabel->setText(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p><a href=\"https://github.com/tesseract-ocr/tessdata\"><span style=\" text-decoration: underline; color:#2980b9;\">Download more</span></a></p></body></html>", nullptr));
        ocrLanguagesPathEdit->setPlaceholderText(QCoreApplication::translate("SettingsDialog", "Directory with trained models", nullptr));
#if QT_CONFIG(tooltip)
        convertLineBreaksCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Replace all single line breaks with a space after text recognition</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        convertLineBreaksCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Convert line breaks", nullptr));
        screenCaptureGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Screen capture", nullptr));
        rememverRegionLabel->setText(QCoreApplication::translate("SettingsDialog", "Remember region:", nullptr));
        rememberRegionComboBox->setItemText(0, QCoreApplication::translate("SettingsDialog", "Never", nullptr));
        rememberRegionComboBox->setItemText(1, QCoreApplication::translate("SettingsDialog", "Remember last", nullptr));
        rememberRegionComboBox->setItemText(2, QCoreApplication::translate("SettingsDialog", "Remember always", nullptr));

#if QT_CONFIG(tooltip)
        rememberRegionComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>When to remember the last selected region</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        captureDelayLabel->setText(QCoreApplication::translate("SettingsDialog", "Capture delay:", nullptr));
#if QT_CONFIG(tooltip)
        captureDelaySpinBox->setToolTip(QCoreApplication::translate("SettingsDialog", "Delay before screen capture", nullptr));
#endif // QT_CONFIG(tooltip)
        captureDelaySpinBox->setSuffix(QCoreApplication::translate("SettingsDialog", " ms", nullptr));
#if QT_CONFIG(tooltip)
        showMagnifierCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Show a magnifier next to the cursor</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        showMagnifierCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Show magnifier", nullptr));
#if QT_CONFIG(tooltip)
        negateOcrCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Negate (invert) the image before OCR. Use for bright text on dark background.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        negateOcrCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Negate OCR", nullptr));
#if QT_CONFIG(tooltip)
        confirmOnReleaseCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Finish capturing the fragment when the mouse button is released</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        confirmOnReleaseCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Confirm on release", nullptr));
#if QT_CONFIG(tooltip)
        applyLightMaskCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Apply a slight fog to the unselected part</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        applyLightMaskCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Apply light mask", nullptr));
        proxyGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Proxy server", nullptr));
        proxyTypeLabel->setText(QCoreApplication::translate("SettingsDialog", "Type:", nullptr));
        proxyTypeComboBox->setItemText(0, QCoreApplication::translate("SettingsDialog", "Use system settings", nullptr));
        proxyTypeComboBox->setItemText(2, QCoreApplication::translate("SettingsDialog", "Don't use a proxy", nullptr));

#if QT_CONFIG(tooltip)
        proxyTypeComboBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Proxy type</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        proxyHostLabel->setText(QCoreApplication::translate("SettingsDialog", "Host:", nullptr));
#if QT_CONFIG(tooltip)
        proxyHostEdit->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Proxy host name</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        proxyHostEdit->setText(QString());
        proxyPortLabel->setText(QCoreApplication::translate("SettingsDialog", "Port:", nullptr));
#if QT_CONFIG(tooltip)
        proxyPortSpinbox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Proxy port</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        proxyInfoLabel->setText(QCoreApplication::translate("SettingsDialog", "Info: the proxy works only for text translation", nullptr));
#if QT_CONFIG(tooltip)
        proxyAuthCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Enable or disable authentication</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        proxyAuthCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Authentication", nullptr));
        proxyUsernameLabel->setText(QCoreApplication::translate("SettingsDialog", "Username:", nullptr));
#if QT_CONFIG(tooltip)
        proxyUsernameEdit->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Proxy username for authentication</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        proxyPasswordLabel->setText(QCoreApplication::translate("SettingsDialog", "Password:", nullptr));
#if QT_CONFIG(tooltip)
        proxyPasswordEdit->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Proxy password for authentication</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        proxyPasswordInfoLabel->setText(QCoreApplication::translate("SettingsDialog", "Info: the password is saved unencrypted", nullptr));
#if QT_CONFIG(tooltip)
        globalShortcutsCheckBox->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Register global shortcuts in system</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        globalShortcutsCheckBox->setText(QCoreApplication::translate("SettingsDialog", "Enable global shortcuts", nullptr));
#if QT_CONFIG(tooltip)
        resetAllShortcutsButton->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Reset all shortcuts to defaults</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        resetAllShortcutsButton->setText(QCoreApplication::translate("SettingsDialog", "Reset all", nullptr));
        shortcutGroupBox->setTitle(QCoreApplication::translate("SettingsDialog", "Shortcut", nullptr));
        shortcutLabel->setText(QCoreApplication::translate("SettingsDialog", "Key sequence:", nullptr));
#if QT_CONFIG(tooltip)
        shortcutSequenceEdit->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>The key sequence for the selected action</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        acceptShortcutButton->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Accept shortcut</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        acceptShortcutButton->setText(QCoreApplication::translate("SettingsDialog", "Accept", nullptr));
#if QT_CONFIG(tooltip)
        clearShortcutButton->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Clear shortcut</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        clearShortcutButton->setText(QCoreApplication::translate("SettingsDialog", "Clear", nullptr));
#if QT_CONFIG(tooltip)
        resetShortcutButton->setToolTip(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Reset shortcut to default</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        resetShortcutButton->setText(QCoreApplication::translate("SettingsDialog", "Reset", nullptr));
        versionTitleLabel->setText(QCoreApplication::translate("SettingsDialog", "Version:", nullptr));
        licenseTitleLabel->setText(QCoreApplication::translate("SettingsDialog", "License:", nullptr));
        sourceTitleLabel->setText(QCoreApplication::translate("SettingsDialog", "Source code:", nullptr));
        backendTitleLabel->setText(QCoreApplication::translate("SettingsDialog", "Translation backend:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsDialog: public Ui_SettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SETTINGSDIALOG_H
